; ##############################################################################
; ##############################################################################
; ##############################################################################
; SPCR => SPIE SPE DORD MSTR CPOL CPHA SPR1 SPR0 (SPI Control Register)		
; 																			
; SPIE: SPI Interrupt Enable												
; SPE:  SPI Enable															
; DORD: Data Order															
; MSTR: Master/Slave Select													
; CPOL: Clock Polarity														
; CPHA: Clock Phase															
;						   Leading Edge 	Trailing Edge 		SPI Mode	
;		CPOL = 0, CPHA = 0 Sample (Rising) 	Setup (Falling) 		0		
;		CPOL = 0, CPHA = 1 Setup (Rising) 	Sample (Falling) 		1		
;*		CPOL = 1, CPHA = 0 Sample (Falling) Setup (Rising) 			2		
;		CPOL = 1, CPHA = 1 Setup (Falling) 	Sample (Rising) 		3		
; SPR1: SPI Clock Rate Select 1												
; SPR0: SPI Clock Rate Select 0												
; 		SPR1 SPR0 SCK Frequency												
;  		0    0   fosc/4														
;  		0    1   fosc/16													
;  		1    0   fosc/64													
;  		1    1   fosc/128													
;																			
; Enable SPI, SLAVE															
SPI_INITIALISIERUNG:
	ldi temp,(0<<SPIE)|(1<<SPE)|(0<<DORD)|(1<<MSTR)|(1<<CPOL)|(0<<CPHA)|(1<<SPR1)|(1<<SPR0)
	out SPCR,temp

; SPSR => SPIF WCOL - - - - - SPI2X  (SPI Status Register )					
;																			
; SPIF:  SPI Interrupt Flag													
; WCOL:  Write COLlision Flag												
; SPI2X: Double SPI Speed Bit												
;																			
; Double SPI Speed = off													
	ldi temp,(0<<SPI2X)
	out SPSR,temp	


; SPI-CS			
	sbi (SPI_CS_DDR),  (SPI_CS_PIN_NR)				; auf AUSGANG	
	sbi (SPI_CS_PORT),(SPI_CS_PIN_NR)				; CS auf HIGH	
; SPI-MOSI			
	sbi (SPI_MOSI_DDR),(SPI_MOSI_PIN_NR)			; auf AUSGANG	
; SPI-MISO			
	cbi (SPI_MISO_DDR),(SPI_MISO_PIN_NR)			; auf EINGANG	
; SPI-SCK			
	sbi (SPI_SCK_DDR), (SPI_SCK_PIN_NR)				; auf AUSGANG	

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Power-Down, Resetting and Clearing the AD9835									
; D15 = 1																		
; D14 = 1																		
; D13 = SLEEP																	
; D12 = RESET																	
; D11 = CLR																		
SPI_DDS_OFF:
	ldi temp1,0xF8				; 'Reset
	ldi temp2,0x00
	rcall SPI_DDS_DATA_TEMP1_2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DDS_ON:
	ldi temp1,0xC0 			;Reset end
	ldi temp2,0x00
	rcall SPI_DDS_DATA_TEMP1_2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DDS_SYNCHRON:
	ldi temp1,0x80 				;'Sync
	ldi temp2,0x00
	rcall SPI_DDS_DATA_TEMP1_2
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DDS_INITIALISIERUNG:

	rcall SPI_DDS_OFF

	ldi temp1,0x30 				;4 Bytes (1kHZ)
	ldi temp2,0x8B
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x21
	ldi temp2,0x4F
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x32
	ldi temp2,0x01
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x23
	ldi temp2,0x00
	rcall SPI_DDS_DATA_TEMP1_2

	rcall SPI_DDS_SYNCHRON

	rcall SPI_DDS_ON

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DDS_DATA_TEMP1_2:
	cbi (SPI_CS_PORT),(SPI_CS_PIN_NR)				; CS auf LOW	
	mov temp,temp1
	rcall SPI_DATA_TEMP
	mov temp,temp2
	rcall SPI_DATA_TEMP
	sbi (SPI_CS_PORT),(SPI_CS_PIN_NR)				; CS auf HIGH	
	rcall SPI_DDS_WAIT
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DATA_TEMP:
	; DATA write	
	out SPDR,temp
SPI_DATA_WAIT:
	; Wait for reception complete
	sbis SPSR,SPIF
	rjmp SPI_DATA_WAIT
	; DATA read		
	in temp, SPDR	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_DDS_WAIT:
	nop
	nop
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 																				
; WERT=f(out) x 2^32          / 50.000.000										
; WERT=f(out) x 4.294.967.296 / 50.000.000										
; WERT=f(out) x 2.882.303.762 / 33.554.432										
; WERT=f(out) x 2.882.303.762 / 2^25											
;																				
SPI_DDS_FREQUENZ_EINSTELLEN:
	; Multiplikation		
	LDS temp1,(adr_FREQUENZ_BYTE0)
	LDS temp2,(adr_FREQUENZ_BYTE1)
	LDS temp3,(adr_FREQUENZ_BYTE2)
	LDS temp4,(adr_FREQUENZ_BYTE3)

	ldi temp5,BYTE1(2882303762)
	ldi temp6,BYTE2(2882303762)
	ldi temp7,BYTE3(2882303762)
	ldi temp8,BYTE4(2882303762)
	rcall MULTIPLIKATION_32_32
	; Division				
	ldi temp,25
SPI_DDS_FREQUENZ_EINSTELLEN_s:
	LSR temp8
	ROR temp7
	ROR temp6
	ROR temp5
	ROR temp4
	ROR temp3
	ROR temp2
	ROR temp1
	dec temp
	brne SPI_DDS_FREQUENZ_EINSTELLEN_s
	; Ergebnis im SRAM speichern	
	STS(adr_DDS_BYTE0),temp1
	STS(adr_DDS_BYTE1),temp2
	STS(adr_DDS_BYTE2),temp3
	STS(adr_DDS_BYTE3),temp4


	; Bytes senden					
	ldi temp1,0x30 				;4 Bytes to FREQ0
	LDS temp2,(adr_DDS_BYTE0)
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x21
	LDS temp2,(adr_DDS_BYTE1)
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x32
	LDS temp2,(adr_DDS_BYTE2)
	rcall SPI_DDS_DATA_TEMP1_2

	ldi temp1,0x23
	LDS temp2,(adr_DDS_BYTE3)
	rcall SPI_DDS_DATA_TEMP1_2

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################


