; #############################################################################
; #############################################################################
; #############################################################################
TWI_INI:
	; SCL(Hz) = CPU(Hz) / (16 + 2 * TWBR * 4^TWPS)	
	; Beispiel:										
	; 100.000 = 16.000.000 / (16 + 2 * 18 * 4^1)	

	; TWI TWBR 				Bit RATE Register	
	ldi temp, TWI_BIT_RATE
	out TWBR, temp
	; TWI TWSR 				STATUS-Register		
	ldi temp, TWI_PRESCALER
	out TWSR, temp
	; TWI TWAR (nur SLAVE) 	Adress-Register		
	clr temp
	out TWAR,temp
	; TWI TWCR 				Control-REGISTER	
	ldi temp, 1<<TWINT|1<<TWEA|0<<TWSTA|0<<TWSTO|0<<TWWC|1<<TWEN|0<<TWIE
	out TWCR,temp
ret
; #############################################################################
; #############################################################################
; #############################################################################
;																			   	
; START-ROUTINE	(MASTER TRANSMITTER)										   	
;																			   	
; INPUT:	temp1 <= ADRESSE SLAVE											   	
; OUT:		FEHLER_CODE/CARRY													
;																			   	
TWI_MASTER_TRANSMITTER_START_TEMP1:
	; 	FEHLER lschen	
	WDR
	clr ERROR_CODE
	; START								
	ldi temp, (1<<TWINT)|(1<<TWSTA)|(1<<TWEN)
	out TWCR, temp	
	; warten, bis TWINT wieder = 1		
	rcall TWI_TWINT_wait									
	; Check TWSR						
	in temp,TWSR													
	andi temp, 0xF8
	cpi temp,  0x08							; 0x08 START erfolgreich
	breq TWI_MASTER_TRANSMITTER_START_TEMP1_w
	cpi temp,  0x10							; 0x10 (repeated START)
	breq TWI_MASTER_TRANSMITTER_START_TEMP1_w
;-------------------------------------------------------------------------------
	; ERROR		
	ldi temp,(ERROR_TWI_MT_START)
	rcall ERROR_SPEICHERN_TEMP
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_START_TEMP1_w:
	; Load SLA + "W"  (W=0) 			
	LSL  temp1								; 1 x links
	out TWDR, temp1
	; senden - Clear TWINT 				
	ldi temp, (1<<TWINT) | (1<<TWEN)							
	out TWCR, temp
	; warten, bis TWINT wieder = 1		
	rcall TWI_TWINT_wait									
	; Check TWSR						
	in temp,TWSR												
	andi temp, 0xF8
	cpi temp,  0x18							; 0x18
	breq TWI_MASTER_TRANSMITTER_START_TEMP1_OK
;-------------------------------------------------------------------------------
	; ERROR		
	ldi temp,(ERROR_TWI_MT_SLA)
	rcall ERROR_SPEICHERN_TEMP
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_START_TEMP1_OK:
	SEC ; SET Carry
ret
; #############################################################################
; #############################################################################
; #############################################################################
; 																			   
; Ein Zeichen zum SLAVE zu senden										   	   
; 																			   
; INPUT:	temp1 <= DATEN													   
; OUT:		ERROR_CODE/CARRY													
; 																			   
TWI_MASTER_TRANSMITTER_DATEN_TEMP1:
	; Daten Zhlen		
	push temp1
	push temp2
	push temp3
	push temp4
	LDS temp1,(adr_ZWISCHENERGEBNIS_BYTE0)
	LDS temp2,(adr_ZWISCHENERGEBNIS_BYTE1)
	LDS temp3,(adr_ZWISCHENERGEBNIS_BYTE2)
	LDS temp4,(adr_ZWISCHENERGEBNIS_BYTE3)
	add temp1,EINS
	adc temp2,NULL
	adc temp3,NULL
	adc temp4,NULL
	STS(adr_ZWISCHENERGEBNIS_BYTE0),temp1
	STS(adr_ZWISCHENERGEBNIS_BYTE1),temp2
	STS(adr_ZWISCHENERGEBNIS_BYTE2),temp3
	STS(adr_ZWISCHENERGEBNIS_BYTE3),temp4
	pop temp4
	pop temp3
	pop temp2
	pop temp1
;-------------------------------------------------------------------------------
	; FEHLERPRFUNG						
	tst ERROR_CODE
	breq TWI_MASTER_TRANSMITTER_DATEN_TEMP1_w
	CLC ; CLEAR CARRY
	ret									
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_DATEN_TEMP1_w:
	; 	Load DATA						
	out TWDR, temp1							
	; senden - Clear TWINT 				
	ldi temp, (1<<TWINT) | (1<<TWEN)							
	out TWCR, temp
	; warten, bis TWINT wieder = 1		
	rcall TWI_TWINT_wait									
	; Check TWSR						
	in temp,TWSR
	andi temp, 0xF8
	cpi temp, 0x28	; 0x28
	breq TWI_MASTER_TRANSMITTER_DATEN_TEMP1_OK
;-------------------------------------------------------------------------------
	; ERROR								
	ldi temp,(ERROR_TWI_MT_DATA)
	rcall ERROR_SPEICHERN_TEMP
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_DATEN_TEMP1_OK:
	SEC ; SET Carry
ret
; #############################################################################
; #############################################################################
; #############################################################################
;																			   
; TWI/I2C START-ROUTINE														   
;																			   
; INP:	temp1 <= ADRESSE SLAVE											   		
; OUT:		ERROR_CODE/CARRY													
;																			   	
TWI_MASTER_RECEIVER_START_TEMP1:
	; FEHLER lschen					
	WDR
	clr ERROR_CODE
	; START 											
	ldi temp, (1<<TWINT | 1<<TWEA | 1<<TWSTA | 1<<TWEN )
	out TWCR, temp	
	; warten, bis TWINT wieder = 1						
	rcall TWI_TWINT_wait
	; Check TWSR 										
	in temp,TWSR		
	andi temp, 0xF8
	cpi temp,  0x08 								; 0x08 START erfolgreich
	breq TWI_MASTER_RECEIVER_START_TEMP1_w
	cpi temp,  0x10									; 0x10 (repeated START)
	breq TWI_MASTER_RECEIVER_START_TEMP1_w
;-------------------------------------------------------------------------------
	; ERROR												
	ldi temp,(ERROR_TWI_MR_START)
	rcall ERROR_SPEICHERN_TEMP
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_START_TEMP1_w:
	; Load SLA +"R" (R=1)								
	LSL  temp1	; 1 x links
	ori temp1, 0b00000001 
	out TWDR, temp1
	; senden - Clear TWINT 								
	ldi temp, (1<<TWINT | 1<<TWEA  | 1<<TWEN )
	out TWCR, temp
	; warten, bis TWINT wieder = 1						
	rcall TWI_TWINT_wait
	; Check TWSR										
	in temp,TWSR
	andi temp, 0xF8
	cpi temp, 0x40 	;SLA+R gesendet; ACK empfangen
	breq TWI_MASTER_RECEIVER_START_TEMP1_OK
;-------------------------------------------------------------------------------
	; ERROR						
	ldi temp,(ERROR_TWI_MR_SLA)
	rcall ERROR_SPEICHERN_TEMP
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_START_TEMP1_OK:
	SEC ; SET Carry
ret
; #############################################################################
; #############################################################################
; #############################################################################
; Mehrere BYTES sollen empfangen werden											
;																				
; OUT:		temp1/ERROR_CODE/CARRY												
;																				
TWI_MASTER_RECEIVER_DATA_TEMP1:
	; Fehlerprfung										
	tst ERROR_CODE
	breq TWI_MASTER_RECEIVER_DATA_TEMP1_w
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_TEMP1_w:
	; senden "ACK" (TWEA=1) fr mehrere Daten-Bytes 	
	ldi temp, (1<<TWINT | 1<<TWEA  | 1<<TWEN )
	out TWCR, temp
	; TWINT abfragen									
	rcall TWI_TWINT_wait
	; Check TWSR										
	in temp,TWSR
	andi temp, 0xF8
	cpi temp, 0x50	; Data Byte empfangen- ACK zurckgesendet
	breq TWI_MASTER_RECEIVER_DATA_TEMP1_OK
;-------------------------------------------------------------------------------
	; ERROR
	ldi temp,(ERROR_TWI_MR_DATA)
	rcall ERROR_SPEICHERN_TEMP	
	CLC ; CLEAR CARRY
	clr temp1
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_TEMP1_OK:
	; DATEN einlesen							
	in temp1, TWDR						
	SEC ; SET Carry
ret
; #############################################################################
; #############################################################################
; #############################################################################
; Ein BYTE oder letztes BYTE soll empfangen werden 								
;																				
; OUT:		temp1/ERROR_CODE/CARRY												
;																				
TWI_MASTER_RECEIVER_DATA_LAST_TEMP1:
	; Fehlerprfung										
	tst ERROR_CODE
	breq TWI_MASTER_RECEIVER_DATA_LAST_TEMP1_w
	CLC ; CLEAR CARRY
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_LAST_TEMP1_w:
	; senden "NOT ACK" (TWEA=0) fr letztes bzw fr ein Daten-Byte
	ldi temp, (1<<TWINT | 0<<TWEA  | 1<<TWEN )
	out TWCR, temp
	; TWINT abfragen									
	rcall TWI_TWINT_wait
	; Check TWSR										
	in temp,TWSR
	andi temp, 0xF8
	cpi  temp, 0x58	; letztes Data Byte empfangen-NOT ACK zurckgesendet
	breq TWI_MASTER_RECEIVER_DATA_LAST_TEMP1_OK	; ERROR
;-------------------------------------------------------------------------------
	; ERROR
	ldi temp,(ERROR_TWI_MR_DATAEND)
	rcall ERROR_SPEICHERN_TEMP	
	CLC ; CLEAR CARRY
	clr temp1
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_LAST_TEMP1_OK:
	; DATEN einlesen		
	in temp1, TWDR
	SEC ; SET Carry
ret
; #############################################################################
; #############################################################################
; #############################################################################
; 																			   
; STOP- Routine																   
; 																			   
TWI_STOP:
	push temp
	ldi temp, (1<<TWINT)|(1<<TWEN)|(1<<TWSTO)|0<<TWIE	; STOP								
	out TWCR, temp	
	; kleine Pause	
	rcall wait_50us
	pop temp
ret
; #############################################################################
; #############################################################################
; #############################################################################
TWI_AUS:
	ldi temp, 1<<TWINT|0<<TWEA|0<<TWSTA|0<<TWSTO|0<<TWWC|0<<TWEN|0<<TWIE
	out TWCR,temp
ret
; #############################################################################
; #############################################################################
; #############################################################################
; 																			   
; ERROR- Routine															   
; 																			   
TWI_ERROR:
	ldi temp, (1<<TWINT)|(1<<TWEN)|(1<<TWSTO)	; TWI STOP				
	out TWCR, temp
	rcall wait_100ms	
	rcall TWI_AUS
ret
; #############################################################################
; #############################################################################
; #############################################################################
; 																			   
; warten, bis das TWINT Flag gesetzt ist									   
; 																			   
TWI_TWINT_wait:
	in temp, TWCR
	sbrs temp, TWINT	; nchsten Befehl berspringen, wenn TWINT FLAG  gesetzt ist
	rjmp TWI_TWINT_wait	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
TWI_BUS_FREE_CHECK:
	in temp,PINC
	com temp
	andi temp,0b00110000
	; Schleife, bis WDR zubeit	
	tst temp
	brne TWI_BUS_FREE_CHECK
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
