;												
;												
; Spektrumanalysator / Frequenzspektrum Analyser
; ATmega8										
; TFT GRAFIC-DISPLAY 320x240 					
; DDS AD9835									
; Logarithmierer AD8307							
; 												
; Bernhard.Erfurt@gmx.de						
; 05/2013										
;												
;												

;												
; Anschlussbelegung PINS						
;												
; PB0 ==> 										
; PB1 ==> 										
; PB2 ==> SPI-CS								
; PB3 ==> SPI-MOSI								
; PB4 ==> 										
; PB5 ==> SPI-SCL								
; PB6 ==> Quarz									
; PB7 ==> Quarz									
;												
; PC0 ==> ADC-0									
; PC1 ==> 										
; PC2 ==> 										
; PC3 ==> 										
; PC4 ==> TWI-SDA								
; PC5 ==> TWI-SCL								
;												
; PD0 ==> LED-GRN								
; PD1 ==> LED-GELB								
; PD2 ==> LED-ROT								
; PD3 ==> 										
; PD4 ==> 										
; PD5 ==>										
; PD6 ==>										
; PD7 ==> 										
;												

; Bedienhinweise:																																				
;																																								
; Nach Programmstart wird sofort der permanente SCAN gestartet (mit den letzten Einstellungen)																	
; Den SCAN-Fortschritt zeigt eine kleine "LAUS" unten an.																										
;																																								
; Diagramm oben links	db/T																																	
; Diagramm oben mitte	Turboschwelle																															
; Diagramm oben rechts	Hz/T																																	
; Diagramm unten links	Startfrequenz																															
; Diagramm unten mitte	Centerfrequenz																															
; Diagramm unten rechts	Stoppfrequenz																															
;																																								
; - TASTE "M" 		unten rechts befindet sich auf dem Display eine versteckte Hauptmenue-Taste (sie ist immer aktiv, aber nicht sichtbar)						
; - TASTE "Scala"	Eingabe dB/T																																
; - TASTE "TS" 		Eingabe "Turboschwelle", wenn sich Messwert sehr stark ndert, wird eine kurze Pause eingelegt und nochmal gemessen							
; - TASTE "Offset" 	Eingabe Verschiebung der KURVE					
; - TASTE "auto" 	Automatik-Offset								
; - TASTE "START"	Eingabe Startfrequenz							
; - TASTE "STOPP"	Eingabe Stoppfrequenz							
; - TASTE "SYSTEM"	Systemmenue anzeigen							
; - TASTE "SCAN"	SCAN + Diagramm									
;																	
; - TASTE "RESET"	Systemreset ber WDR							
; - TASTE "hell"	Eingabe Helligkeit								
; - TASTE "FREQ"	Eingabe manuelle Frequenz						
; - TASTE "ZF-320"	SCAN 2MHz ZF-Filter (Bandbreite 320Hz)			
; - TASTE "ZF-640"	SCAN 2MHz ZF-Filter (Bandbreite 640Hz)			
; - TASTE "ZF-1280"	SCAN 2MHz ZF-Filter (Bandbreite 1280Hz)			
; - TASTE "INFO"	TFT Info anzeigen								
; - TASTE "STATUS"	wichtige Systemzustnde anzeigen				
;																																								
; Programmhinweise:																																				
; - Maximal 4 Kurven knnen angezeigt werden (gegenwrtig ist nur eine programmiert)																			
; - Bei bertragungsfehlern --> TWI-Bitrate erhhen																												
; - Interrupts sind aktiviert, werden aber nicht bentigt, dient zur Aufdeckung von Programmierfehlern															
; - Scandauer ca. 20 Sekunden																																	
;																																								
;																																								


; ATmega8 										
.include "m8def.inc"
; KONSTANTEN									
.equ TAKT							= 16000000			; 16 MHz	
; SPI-CS										
.equ SPI_CS_PIN_NR					= 2
.equ SPI_CS_DDR						= DDRB
.equ SPI_CS_PORT					= PORTB
; SPI-MOSI										
.equ SPI_MOSI_PIN_NR				= 3
.equ SPI_MOSI_DDR					= DDRB
.equ SPI_MOSI_PORT		 			= PORTB
; SPI-MISO										
.equ SPI_MISO_PIN_NR				= 4
.equ SPI_MISO_DDR					= DDRB
.equ SPI_MISO_PORT		 			= PORTB
; SPI-SCK										
.equ SPI_SCK_PIN_NR					= 5
.equ SPI_SCK_DDR					= DDRB
.equ SPI_SCK_PORT		 			= PORTB
; LED-GRUEN										
.equ LED_GRUEN_PIN_NR				= 0
.equ LED_GRUEN_DDR					= DDRD
.equ LED_GRUEN_PORT					= PORTD
; LED-GELB										
.equ LED_GELB_PIN_NR				= 1
.equ LED_GELB_DDR					= DDRD
.equ LED_GELB_PORT					= PORTD
; LED-ROT										
.equ LED_ROT_PIN_NR					= 2
.equ LED_ROT_DDR					= DDRD
.equ LED_ROT_PORT					= PORTD
; ADC-REFERENZ									
.equ ADC_REFERENZ					= 2560		; mV	
; TWI ADRESSEN									
.equ TWI_ADRESSE_DISPLAY	= 110	; DISPLAY	
; TWI MASTER EINSTELLUNGEN						
.equ TWI_BIT_RATE			=75		; 100	; Bit-Rate							
.equ TWI_PRESCALER			=0		; 0		; Vorteiler: 0=1 1=4 2=16 3=64		
; ERROR-CODES									
.equ ERROR_GRAFIC_SENDEN	= 8		; Verbindungsfehler		

.equ ERROR_TWI_MT_START		= 10
.equ ERROR_TWI_MT_SLA		= 12
.equ ERROR_TWI_MT_DATA		= 14
.equ ERROR_TWI_MR_START		= 20
.equ ERROR_TWI_MR_SLA		= 21
.equ ERROR_TWI_MR_DATA		= 22
.equ ERROR_TWI_MR_DATAEND	= 23
; GRAFIC-FARBEN									
.equ FARBE_TRANSPARENT		= 0
.equ FARBE_SCHWARZ			= 1
.equ FARBE_BLAU				= 2
.equ FARBE_ROT				= 3 
.equ FARBE_GRUEN			= 4
.equ FARBE_GELB				= 7
.equ FARBE_WEISS			= 8
.equ FARBE_DUNKEL_GRAU		= 9
.equ FARBE_GRAU				= 16
; DIAGRAMM-Einstellungen						
.equ FARBE_RASTER			= FARBE_DUNKEL_GRAU
.equ FARBE_LAUS				= FARBE_ROT
.equ FARBE_KURVE_A			= FARBE_GELB
.equ FARBE_KURVE_B			= FARBE_GRUEN
.equ FARBE_KURVE_C			= FARBE_BLAU
.equ FARBE_KURVE_D			= FARBE_ROT

; REGISTER										
.def ERROR_CODE		= R8

.def NULL 			= R10
.def EINS 			= R11


.def temp 			= R16
.def temp1 			= R17
.def temp2 			= R18
.def temp3 			= R19
.def temp4 			= R20
.def temp5 			= R21
.def temp6 			= R22
.def temp7 			= R23
.def temp8 			= R24
.def temp9 			= R25

; SRAM-BELEGUNG ATmega8							
.equ adr_DATEN							=SRAM_START			; 0x0060 START Adresse 							

.equ adr_TASTE							=SRAM_START+1		; TASTENWERT (TFT-DISPLAY oder andere Tasten)	

.equ adr_MENUE							=SRAM_START+2		; MENUE											

.equ adr_ERROR							=SRAM_START+4		; ERROR			

.equ adr_ADC_0_L						=SRAM_START+10		; ADC			
.equ adr_ADC_0_H						=SRAM_START+11
.equ adr_ADC_0_OLD_L					=SRAM_START+12
.equ adr_ADC_0_OLD_H					=SRAM_START+13

.equ adr_EINGABE_ZAHL_FERTIG			=SRAM_START+20		; fr Zahleneingabe	per TST-DISPLAY	
.equ adr_EINGABE_ZAHL_BYTE0				=SRAM_START+21
.equ adr_EINGABE_ZAHL_BYTE1				=SRAM_START+22
.equ adr_EINGABE_ZAHL_BYTE2				=SRAM_START+23
.equ adr_EINGABE_ZAHL_BYTE3				=SRAM_START+24

.equ adr_FREQUENZ_BYTE0					=SRAM_START+30		; DDS-Frequenz in Hz	
.equ adr_FREQUENZ_BYTE1					=SRAM_START+31		
.equ adr_FREQUENZ_BYTE2					=SRAM_START+32		
.equ adr_FREQUENZ_BYTE3					=SRAM_START+33	

.equ adr_DDS_BYTE0						=SRAM_START+34		; DDS-SENDE-BYTES		
.equ adr_DDS_BYTE1						=SRAM_START+35
.equ adr_DDS_BYTE2						=SRAM_START+36
.equ adr_DDS_BYTE3						=SRAM_START+37
		
.equ adr_FREQUENZ_START_BYTE0			=SRAM_START+40		; Frequenz-Start		
.equ adr_FREQUENZ_START_BYTE1			=SRAM_START+41
.equ adr_FREQUENZ_START_BYTE2			=SRAM_START+42		
.equ adr_FREQUENZ_START_BYTE3			=SRAM_START+43	

.equ adr_FREQUENZ_STOPP_BYTE0			=SRAM_START+45		;  Frequenz-Stopp		
.equ adr_FREQUENZ_STOPP_BYTE1			=SRAM_START+46		
.equ adr_FREQUENZ_STOPP_BYTE2			=SRAM_START+47		
.equ adr_FREQUENZ_STOPP_BYTE3			=SRAM_START+48	

.equ adr_FREQUENZ_CENTER_BYTE0			=SRAM_START+50		; Center-Frequenz ((Stopp-Start):2)
.equ adr_FREQUENZ_CENTER_BYTE1			=SRAM_START+51		
.equ adr_FREQUENZ_CENTER_BYTE2			=SRAM_START+52		
.equ adr_FREQUENZ_CENTER_BYTE3			=SRAM_START+53	

.equ adr_FREQUENZ_STEP_BYTE0			=SRAM_START+55		; Frequenz-Schrittweite	
.equ adr_FREQUENZ_STEP_BYTE1			=SRAM_START+56		
.equ adr_FREQUENZ_STEP_BYTE2			=SRAM_START+57		
.equ adr_FREQUENZ_STEP_BYTE3			=SRAM_START+58	

.equ adr_FREQUENZ_SPAN_BYTE0			=SRAM_START+60		; Frequenz-Spanne (fr Diagramm)
.equ adr_FREQUENZ_SPAN_BYTE1			=SRAM_START+61	
.equ adr_FREQUENZ_SPAN_BYTE2			=SRAM_START+62		
.equ adr_FREQUENZ_SPAN_BYTE3			=SRAM_START+63	

.equ adr_DIAGRAMM_Y_SKALA				=SRAM_START+64		; Diagramm Y-Skala (dB)			
.equ adr_DIAGRAMM_TURBO_SCHWELLE		=SRAM_START+65

.equ adr_DIAGRAMM_OPTION_LAUS_EIN		=SRAM_START+70		; Laus zeichnen (kleiner Punkt unten)	
.equ adr_DIAGRAMM_OPTION_CLEAR_EIN		=SRAM_START+71		; vorhergehende Kurve clear				
.equ adr_DIAGRAMM_OPTION_KURVE_A_EIN	=SRAM_START+72		; Kurve-A ein							
.equ adr_DIAGRAMM_OPTION_KURVE_B_EIN	=SRAM_START+73		; Kurve-B ein							
.equ adr_DIAGRAMM_OPTION_KURVE_C_EIN	=SRAM_START+74		; Kurve-C ein							
.equ adr_DIAGRAMM_OPTION_KURVE_D_EIN	=SRAM_START+75		; Kurve-D ein							

.equ adr_DIAGRAMM_Y_OFFSET_BYTE0		=SRAM_START+80		; Diagramm-Offset-Wert		
.equ adr_DIAGRAMM_Y_OFFSET_BYTE1		=SRAM_START+81
.equ adr_DIAGRAMM_Y_OFFSET_BYTE2		=SRAM_START+82
.equ adr_DIAGRAMM_Y_OFFSET_BYTE3		=SRAM_START+83


.equ adr_DIAGRAMM_SPALTE_L				=SRAM_START+85		; fr DIAGRAMM-DARSTELLUNG	(0...319)	
.equ adr_DIAGRAMM_SPALTE_H				=SRAM_START+86

.equ adr_DIAGRAMM_Y_WERT_A				=SRAM_START+90		; Y-Wert Kurve-A							
.equ adr_DIAGRAMM_Y_WERT_B				=SRAM_START+91		; Y-Wert Kurve-B							
.equ adr_DIAGRAMM_Y_WERT_C				=SRAM_START+92		; Y-Wert Kurve-C							
.equ adr_DIAGRAMM_Y_WERT_D				=SRAM_START+93		; Y-Wert Kurve-D							

.equ adr_DIAGRAMM_Y_WERT_A_OLD			=SRAM_START+94		; Y-Wert Kurve-A (fr Liniendarstellung)	
.equ adr_DIAGRAMM_Y_WERT_B_OLD			=SRAM_START+95		; Y-Wert Kurve-B (fr Liniendarstellung)	
.equ adr_DIAGRAMM_Y_WERT_C_OLD			=SRAM_START+96		; Y-Wert Kurve-C (fr Liniendarstellung)	
.equ adr_DIAGRAMM_Y_WERT_D_OLD			=SRAM_START+97		; Y-Wert Kurve-D (fr Liniendarstellung)	


.equ adr_ZWISCHENERGEBNIS_BYTE0			=SRAM_START+200
.equ adr_ZWISCHENERGEBNIS_BYTE1			=SRAM_START+201
.equ adr_ZWISCHENERGEBNIS_BYTE2			=SRAM_START+202
.equ adr_ZWISCHENERGEBNIS_BYTE3			=SRAM_START+203


.equ adr_GRAFIC_PUFFER_TX_ZEIGER		=SRAM_START+600		; TFT-DISPAY					
.equ adr_GRAFIC_PUFFER_256				=SRAM_START+601		; TFT-DISPAY-PUFFER				

.equ adr_SRAM_CHECK						=SRAM_START+943		; SRAM CHECK muss immer "S" sein


.cseg					;Beginn eines Code-Segmentes
.org 0					;Startadresse=0

rjmp RESET      		; Reset Handler                           				
rjmp INTERRUPT_ERROR	;rjmp EXT_INT0   ; IRQ0 Handler                      	
rjmp INTERRUPT_ERROR	;rjmp EXT_INT1   ; IRQ1 Handler                      	
rjmp INTERRUPT_ERROR	;rjmp TIM2_COMP  ; Timer2 Compare Handler            	
rjmp INTERRUPT_ERROR	;rjmp TIM2_OVF   ; Timer2 Overflow Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_CAPT  ; Timer1 Capture Handler            	
rjmp INTERRUPT_ERROR	;rjmp TIM1_COMPA ; Timer1 CompareA Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_COMPB ; Timer1 CompareB Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_OVF   	  	; Timer1 Overflow Handler       
rjmp INTERRUPT_ERROR	;rjmp TIM0_OVF   		; Timer0 Overflow Handler       
rjmp INTERRUPT_ERROR	;rjmp SPI_STC    ; SPI Transfer Complete Handler     	
rjmp INTERRUPT_ERROR	;rjmp ZEICHEN_EINLESEN 	; USART RX Complete Handler     
rjmp INTERRUPT_ERROR	;rjmp USART_UDRE ; UDR Empty Handler                 	
rjmp INTERRUPT_ERROR	;rjmp USART_TXC  ; USART TX Complete Handler         	
rjmp INTERRUPT_ERROR	;rjmp ADC        ; ADC Conversion Complete Handler   	
rjmp INTERRUPT_ERROR	;rjmp EE_RDY     ; EEPROM Ready Handler              	
rjmp INTERRUPT_ERROR	;rjmp ANA_COMP   ; Analog Comparator Handler         	
rjmp INTERRUPT_ERROR	;rjmp TWSI       ; Two-wire Serial Interface Handler 	
rjmp INTERRUPT_ERROR	;rjmp SPM_RDY    ; Store Program Memory Ready Handler	


; Unkorrekter Interrupt Aufruf
INTERRUPT_ERROR:
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	rcall wait_100ms
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus  
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	rcall wait_100ms
	rjmp INTERRUPT_ERROR

RESET:                        
; STACK initialisieren								
	ldi temp, LOW(RAMEND)
    out SPL, temp
    ldi temp, HIGH(RAMEND)
    out SPH, temp
; PORT B initialisieren								
	ldi temp, 0b00000000	; 
	out DDRB, temp
; PORT B setzen										
	ldi temp, 0b00000000
	out PORTB, temp				
; PORT C initialisieren								
	ldi temp, 0b00000000	; 
	out DDRC, temp
; PORT C setzen										
	ldi temp, 0b00000000
	out PORTC, temp				
; PORT D initialisieren								
	ldi temp, 0b00000000	; 
	out DDRD, temp
; PORT D setzen										
	ldi temp, 0b00000000	
	out PORTD, temp				
; LED-INITIALISIERUNG								
	rcall LED_INITIALISIERUNG
; WDR-INITIaLISIERUNG								
	rcall WDR_INITIALISIERUNG
	rcall NEUSTART_MIT_WDR
; SRAM CLEAR										
	rcall SRAM_CLEAR
; STARTWERTE										
	; NULL				
	clr NULL
	; EINS				
	ldi temp,1
	mov EINS,temp
	; SRAM CHECK		
	ldi temp,'S'
	STS(adr_SRAM_CHECK),temp
; EEPROM							
	rcall EEPROM_KONFIGURATION_LADEN
; ADC-INITIALISIERUNG				
	rcall ADC_INITIALISIERUNG
; TWI-INITIALISIERUNG				
	rcall TWI_INI
	rcall ANZEIGE_BEGRUESSUNG
	rcall wait_1s
; SPI-INITIALISIERUNG				
	rcall SPI_INITIALISIERUNG
; SPI-DDS-INITIALISIERUNG			
	rcall SPI_DDS_INITIALISIERUNG
; Interrupts freigeben								
	sei
	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an   
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	STS(adr_ERROR),NULL

	rcall TASTEN_ABFRAGEN
	rcall MENUE_01_HAUPTMENUE
	rcall wait_100Ms
 	rcall DIAGRAMM_SCAN
; ##############################################################################
; ##############################################################################
; ##############################################################################
LOOP:
	WDR
	rcall TASTEN_ABFRAGEN
	rcall MENUE
	rcall PROGRAMM_CHECK
	rcall ERROR_CHECK
	rcall TWI_BUS_FREE_CHECK
	rcall wait_100ms
	rcall wait_100ms
rjmp LOOP
; ##############################################################################
; ##############################################################################
; ##############################################################################
.include "MASTER_GRAFIC.asm"					; DISPLAY					
.include "MASTER_GRAFIC_PAKET.asm"				; DISPLAY-PROTOKOLL-PAKET	
.include "MASTER_GRAFIC_ANZEIGE.asm"			; DISPLAY-ANZEIGE			
.include "MASTER_GRAFIC_ANZEIGE_KURZ.asm"		; DISPLAY-ANZEIGE			
.include "MASTER_GRAFIC_DIAGRAMM.asm"
.include "MASTER_GRAFIC_ZAHLEN.asm"				; DISPLAY-ZAHLENWERTE		
.include "MASTER_TASTEN.asm"					; DISPLAY-TASTEN+SCHALETR	
.include "MASTER_MENUE.asm"

.include "MASTER_SPI_DDS.asm"


.include "MASTER_TWI.asm"						; TWI-MASTER				
.include "MASTER_SONSTIGES.asm"					; LED-TEST usw.				
.include "MASTER_FUNKTIONEN.asm"
.include "MASTER_EEPROM.asm"
.include "MASTER_ADC.asm"
.include "MASTER_wait_16MHZ.asm"				; 16 MHZ Takt				
;.include "MASTER_wait_08MHZ.asm"				;  8 MHZ Takt				
;-------------------------------------------------------------------------------
; Begrungstext						
TEXT_BEGRUESSUNG_1:
.db "Spektrumanalysator 1kHz-1MHz",0
TEXT_BEGRUESSUNG_2:
.db "TFT DISPLAY 240x320 EA eDIPTFT32-ATP",0
TEXT_BEGRUESSUNG_3:
.db "ATmega8 / 16MHz ",0
TEXT_BEGRUESSUNG_4:
.db "DDS AD9835",0
TEXT_BEGRUESSUNG_5:
.db "AD8307",0
TEXT_BEGRUESSUNG_6:
.db "Bernhard.Erfurt@gmx.de",0
TEXT_BEGRUESSUNG_7:
.db "03.05.2013",0
; andere Texte		
TEXT_KORREKTUR:
.db "Diagramm Einstellungen korrigiert",0

;-------------------------------------------------------------------------------
;   X1,Y1,X2,Y2, WT,TEXT,27														
; X1=Position Taste 					
; Y1=Position Taste 					
; X2=Breite der Taste					
; Y2=Hhe der Taste						
; WT=Rckgabewert wenn Taste gedrckt	
; TEXT=Tasten Text						
; 27="27" Erkennung Ende des Textes		

TASTE_01_SONDERTASTE:	; kleine TASTE unten rechts "M"
.dw 280,200, 30, 30, 1, 'M',27


; Hauptmenue	
TASTE_22_SCALA:
.dw 10,  0, 90,30,22,  'S','c','a','l','a',27
TASTE_24_OFFSET:
.dw 10, 50, 90,30,24,  'O','f','f','s','e','t',27
TASTE_18_FREQUENZ_START:
.dw 10,100, 90,30,18,  'S','T','A','R','T',27
TASTE_60_DIAGRAMM_SCAN:
.dw 10,200,200,30,60, 'S','C','A','N',27

TASTE_23_TURBOSCHWELLE:
.dw 110,  0,90,30,23,  'T','S',27
TASTE_25_OFFSET_AUTO:
.dw 110, 50,90,30,25,  'a','u','t','o',27
TASTE_19_FREQUENZ_STOPP:
.dw 110,100,90,30,19,  'S','T','O','P','P',27


TASTE_10_SYSTEM:
.dw 210,0, 90, 30,10, 'S','Y','S','T','E','M',27



; System	
TASTE_20_RESET:
.dw 10, 50,90,30,7,  ' ','R','E','S','E','T',27
TASTE_13_HELLIGKEIT:
.dw 10,100,90,30,13,  'h','e','l','l',27
TASTE_16_FREQUENZ:
.dw 10,150,90,30,16,  'F','R','E','Q',27

TASTE_62_DIAGRAMM_ZF:
.dw 110, 0, 90, 30, 62, 'Z','F','-','3','2','0',27
TASTE_64_DIAGRAMM_ZF:
.dw 110, 50,90, 30, 64, 'Z','F','-','6','4','0',27
TASTE_66_DIAGRAMM_ZF:
.dw 110,100,90, 30, 66, 'Z','F','-','1','2','8','0',27



TASTE_14_INFO:
.dw 210, 0, 90, 30, 6,  'I','N','F','O',27
TASTE_21_STATUS:
.dw 210,150, 90, 30, 5,  'S','T','A','T','U','S',27





; ZAHLENFELD	
TASTE_101_ZAHL_1:	
.dw  50,50, 50, 50, 101, '1',27
TASTE_102_ZAHL_2:	
.dw 100,50, 50, 50, 102, '2',27
TASTE_103_ZAHL_3:	
.dw 150,50, 50, 50, 103, '3',27
TASTE_104_ZAHL_4:	
.dw  50,100, 50, 50, 104, '4',27
TASTE_105_ZAHL_5:	
.dw 100,100, 50, 50, 105, '5',27
TASTE_106_ZAHL_6:	
.dw 150,100, 50, 50, 106, '6',27
TASTE_107_ZAHL_7:	
.dw  50,150, 50, 50, 107, '7',27
TASTE_108_ZAHL_8:	
.dw 100,150, 50, 50, 108, '8',27
TASTE_109_ZAHL_9:	
.dw 150,150, 50, 50, 109, '9',27
TASTE_110_ZAHL_0:	
.dw 100,200, 50, 50, 110, '0',27
; ZAHLENFELD	
TASTE_111_ZAHL_OK:
.dw 250,150 ,60, 50, 111,  'O','K',27
TASTE_112_ZAHL_ESC:
.dw 250, 0 ,60, 50, 112,  'E','s','c',27
TASTE_113_ZAHL_BACK:
.dw 250, 50 ,60, 50, 113,  'B','a','c','k',27







